#!/bin/bash

######################################################
#
#Delete from archive according the id touched in the docs2delete folder 
#	Skript: docs2delete.sh
#
#	Parameter:
#			<Pfad des Basisverzeichnisses> Prozessingverzeichnis
#			<dsm.opt Dateien>
#
#
#
#
#
#
#
######################################################

function exists {
 local i
 for i in ${arrSERVICES[@]}; do
	if [ "$i" == "$1" ]; then
		return 0
	fi
 done
 return 1
}

function checkarchive
{
	DSMC_BINPATH="/opt/tivoli/tsm/client/ba/bin"
	
	service=$1
	job_id=$2
	if [ ! -e ${DSMC_BINPATH}/dsmc ]; then
		echo "[FE] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ENDE Archiv-Client dsmc in $DSMC_BINPATH nicht gefunden." >> $LOGFILE
		return 1
	fi	
	dsmc_cmd="$DSMC_BINPATH/dsmc query archive /$service/${job_id}*.tar -optfile=${tsm_optfile}"
	dsmc_string=`$dsmc_cmd`
	return $?
}


LOGFILE="/var/log/jobs/archive/$(hostname)_delete_processing_`date +%Y%m%d`.log"
LOCKFILE="/var/locks/docs2delete.lock"

arrSERVICES=("mediathek" "goobi" "fotothek")

echo "[OK] `date +%Y%m%d\ %T` START PID: $$ $0 $*" >> $LOGFILE

#Prüft ob Anzahl der Übergabeparameter stimmt
if [ $# -lt 1 ]; then
	echo "[FE] `date +%Y%m%d\ %T` docs2delete.sh ENDE Zu wenig Parameter uebergeben." >> $LOGFILE
	exit 1
fi

#Prueft ob schon ein Delete Prozess gestartet ist
if [ -e $LOCKFILE ]; then
        echo "[FE] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ENDE Skript laeuft scheinbar schon, lockfile '$LOCKFILE' existiert." >> $LOGFILE
        exit 1
else
        echo $$ > $LOCKFILE
fi


# Pfad zu Archiv Client (TSM)
DSMC_BINPATH="/opt/tivoli/tsm/client/ba/bin"
SCRIPT=$(readlink -f $0)
SCRIPT_PATH=`dirname $SCRIPT`


#echo $SCRIPT_PATH

#Prüft ob Archiv-Client installiert ist
if [ ! -e ${DSMC_BINPATH}/dsmc ]; then
	echo "[FE] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ENDE Archiv-Client dsmc in $DSMC_BINPATH nicht gefunden." >> $LOGFILE
	exit 1
fi

# Übergabeparameter initialisiert
basefolder=$1
tsm_optfile=$2

i=0
#Einlesen aller IDs aus dem Basisverzeichnis/docs2delete und starten des Prozessing
for job_id in `ls $basefolder/docs2delete`
do
	# pattern matching, alles vor dem ersten _ wird von $job_id zurueck gegeben (id=goobi_1234567_data -> service=goobi)
	service=${job_id%%_*} 
	
	
	## Prüfe ob korrekter Service entsprechend Liste angegeben ist und nichts anderes
	if [ "$(exists $service)" == "1" ]; then
		echo "[ERROR] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ${basefolder}/${job_id} does not map to a correct service: $service." >> ${LOGFILE}
		continue
	fi
		
	# pattern matching ready jobid format, others shall not delete from archive (forbidden), urgent: only implemented for service: goobi (other services may be need different reg_form)
	reg_form=$service"_[0-9]+_data"
		
	#cmd_regex="/usr/bin/perl" $SCRIPT_PATH"/checkidformat.pl" $job_id  "^$reg_form$"
	cmd_regex="/usr/bin/perl $SCRIPT_PATH/checkidformat.pl $job_id  ^$reg_form$"
		
	return=`$cmd_regex`
		
	if ! [ "${return}" == "matched" ]; then
		echo "[ERROR] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ${basefolder}/${job_id} does not look like correct ID format [e.g. goobi_1234_data]." >> ${LOGFILE}
		continue
	fi
	
	# prüft in Unterfunktion: checkarchive() ob zu der ID eine/meherere Archivpaket/e vorhanden sind
	checkarchive $service $job_id
	
	if [ $? != 0 ]; then
		echo "[FE] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} Kein Archivpaket für $job_id vorhanden." >> $LOGFILE
		continue
	fi
	echo "[OK] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ${basefolder}/${job_id} im Archiv vorhanden." >> $LOGFILE
	
	
	ieId=${job_id#*_}
	ieId=${ieId%%_*}

	if ! [[ "${ieId}" =~ ^[0-9]+$ ]] ; then
		echo "[ERROR] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ${basefolder}/${job_id} does not look like correct ieID [e.g. '[0-9]+']." >> ${LOGFILE}
		continue
	fi

	if [ -n $job_id ]; then
		dsmc_cmd="$DSMC_BINPATH/dsmc delete archive -noprompt /$service/${job_id}*.tar -optfile=${tsm_optfile}"
		dsmc_string=`$dsmc_cmd`
		if [ $? == 0 ]; then
			echo "[OK] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} Verzeichnis ${basefolder}/${job_id} erfolgreich geloescht." >> $LOGFILE
			echo "[OK] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} Verzeichnis ${basefolder}/${job_id} erfolgreich geloescht."| mail -s "Delete Job from Archive: $archive_id erfolgreich beendet!" kru@slub-dresden.de steffen.warncke@slub-dresden.de henning.gerhardt@slub-dresden.de
			rm -f $basefolder/docs2delete/$job_id | awk '{print "[FE] '"\`date +%Y%m%d\ %T\`"' " $0}' 2>&1 >> $LOGFILE
		else
			echo "[FE] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} Verzeichnis ${basefolder}/${job_id} nicht geloescht FehlerNr: $?." >> $LOGFILE
		fi
	fi
done


echo "[OK] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ENDE " >> $LOGFILE
`rm -f $LOCKFILE 2>&1 >> $LOGFILE`
exit 0

