#!/bin/bash

######################################
#
# docs2restore.sh
#
#       Syntax: docs2retore.sh <Basisordner> <dateiname> <dsm.opt>
#
#
#
#
#
#
#
#
#
######################################

# Pfad zu dsmc (Archiv Client)
DSMC_BINPATH="/usr/tivoli/tsm/client/ba/bin"

# Logfile
LOGFILE="/var/log/jobs/restore_processing/restore_processing_`date +%Y%m%d`.log"


# Script zur MD5 Erstellung
CREATE_MD5='perl /opt/scripts/create_md5.pl'

starttime=$[`date +%s`]

# Logfile erstellen
echo "[OK] `date +%Y%m%d\ %T` START PID: $$ $0 $*" >> $LOGFILE

# Einige checks
if [ $# -lt 3 ]; then
        echo "[FE] `date +%Y%m%d\ %T` docs2restore.sh ENDE Zu wenig Parameter uebergeben." >> $LOGFILE

        exit 1
fi

if [ ! -e ${DSMC_BINPATH}/dsmc ]; then
        echo "[FE] `date +%Y%m%d\ %T` docs2restore.sh ENDE Archiv-Client dsmc in $DSMC_BINPATH nicht gefunden." >> $LOGFILE
        exit 1
fi

# Parameter uebergeben
basefolder=$1
file_name=$2
tsm_optfile=$3

readyfiledir="${basefolder}/docs2restore"

# Ausgabe Verzeichnisse
RESTORE_DIR="${basefolder}/restored"

# Herausfinden, zu welchem Dienst das Archiv gehoert (z.B. goobi, fotothek, ...)
service=${file_name%%.*}       # pattern matching, alles vor dem ersten _ wird zurueck gegeben

if [ ! -e $tsm_optfile ]; then
        echo "[FE] `date +%Y%m%d\ %T` $tsm_optfile existiert nicht." >> $LOGFILE
        exit 1l
fi

# Lockfile erstellen und PID eintragen
LOCKFILE="/var/locks/"${service}"_docs2restore.lock"
if [ -e $LOCKFILE ]; then
        echo "[FE] `date +%Y%m%d\ %T` docs2restore.sh ENDE Skript laeuft scheinbar schon, lockfile '$LOCKFILE' existiert." >> $LOGFILE
        `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
        exit 1
else
        echo $$ > $LOCKFILE
fi

# Readydatei umbenennen, Workdatei erstellen
if [ -e ${readyfiledir}/~${file_name} ]; then
        echo "[FE] `date +%Y%m%d\ %T` ENDE Work-Datei $readyfiledir/~${file_name} existiert bereits." >> $LOGFILE
        `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
        exit 1
elif [ ! -e $readyfiledir/$file_name ]; then
        echo "[FE] `date +%Y%m%d\ %T` ENDE Readydatei $readyfiledir/${file_name} existiert nicht." >> $LOGFILE
        `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
        exit 1
else    
#fuer Testzwecke
        `cp -f $readyfiledir/$file_name $basefolder/restore_test/$file_name`
        `mv $readyfiledir/$file_name $readyfiledir/~$file_name`
	workfile=$readyfiledir/~$file_name
fi

tarballpath="/${service}/${archive_id}_*.tar"


#Query
#dsmc_cmd="$DSMC_BINPATH/dsmc query archive \"$tarballpath\" -optfile=$tsm_optfile"

# Abfragen des Archivs, grep nach archive_id, Sortieren nach nach der archive_id absteigend, Ausgabe letzte Zeile (hoechste archive_id, damit neuestes Paket), Filtern des Archivpfades und des MD5 Hashes

# Beispiel dsmc_string "/goobi/goobi_6256_data_20111011065955.tar 66cac34fa21b0184714ebe7fc6471e6f"
dsmc_string=`$dsmc_cmd|grep ${archive_id}|sort -k 5,5|tail -1|awk '{print $5" "$8}'`

# Beispiel /goobi/goobi_6256_data_20111011065955.tar
tarballpath=${dsmc_string%[ ]*}

# Beispiel 66cac34fa21b0184714ebe7fc6471e6f
archive_tarmd5sum=${dsmc_string##*[ ]}

# Beispiel goobi_6256_data_20111011065955.tar
archive_id=${tarballpath##*/}

retrieve_time=$[`date +%s`]
# Retrieve
dsmc_cmd="$DSMC_BINPATH/dsmc restore /san/archiv/digitalisate/${file_name}*.tif ${RETRIEVE_DIR}/  -optfile=$tsm_optfile" 
echo "[OK] `date +%Y%m%d\ %T` Restore von $file_name beginnt." >> $LOGFILE
`$dsmc_cmd | awk '{print "[OK] '"\`date +%Y%m%d\ %T\`"' " $0}' 2>&1 >> $LOGFILE`
if [ $? != 0 ]; then
        echo "[FE] `date +%Y%m%d\ %T` Restore von $file_name nicht erfolgreich." >> $LOGFILE
	echo "[FE] `date +%Y%m%d\ %T` Kommando: ${dsmc_cmd}" >> $LOGFILE
        `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
        exit 1
fi
restoree_time=$[`date +%s`-$restore-time]

if [ -e ${RESTORE_DIR}/${file_name} ]; then
	tarballpath=${RESTORE_DIR}/${file_name}
	tarsize=`du -m $tarballpath | awk '{print $1}'`
else
	echo "[FE] `date +%Y%m%d\ %T` ${RESTORE_DIR}/${file_name} nicht vorhanden." >> $LOGFILE
        `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
        exit 1
fi

# MD5 Pruefsumme des Tarballs bilden und mit Archivdescription vergleichen
tarmd5sum=`nice -n 19 $CREATE_MD5 $tarballpath`
if [ "${tarmd5sum}" == "${archive_tarmd5sum}" ]; then
	echo "[OK] `date +%Y%m%d\ %T` Pruefsummenvergleich erfolgreich: MD5: $tarmd5sum Archiv-MD5: $archive_tarmd5sum" >> $LOGFILE
else
	echo "[FE] `date +%Y%m%d\ %T` Pruefsummenvergleich gescheitert: MD5: $tarmd5sum Archiv-MD5: $archive_tarmd5sum" >> $LOGFILE
	`rm -f $LOCKFILE 2>&1 >> $LOGFILE`
	exit 1;
fi

# untar
if [ -e $tarballpath ]; then
	untar_cmd="tar -x -p -f $tarballpath"
else
	echo "[FE] `date +%Y%m%d\ %T` Abbruch, $tarballpath existiert nicht"
fi

# .tar entfernen
archive_id=${archive_id%\.*}

cd $RETRIEVE_DIR
echo "[OK] `date +%Y%m%d\ %T` Enpacken des Tarballs." >> $LOGFILE
untar_string=`$untar_cmd | awk '{print "[OK] '"\`date +%Y%m%d\ %T\`"' " $0}' 2>&1 >> $LOGFILE`
if [[ -e $RETRIEVE_DIR/$archive_id/"images/scans_tif/00000001.tif" || -e $RETRIEVE_DIR/$archive_id/"images/scans_tif/00000001.TIF" ]]; then
	duration=$[`date +%s`-$starttime]
	duration_string="$[$duration/3600]h $[$duration %3600 /60]min $[$duration%60]s"
	echo "[OK] `date +%Y%m%d\ %T` ENDE Retrieve $0 $* Dauer: $duration s ($duration_string) Tarballgroesse: $tarsize MB Retrieve-Dauer: ${retrieve_time} s" >> $LOGFILE
	echo "[OK] `date +%Y%m%d\ %T` ENDE Retrieve $0 $* Dauer: $duration s ($duration_string) Tarballgroesse: $tarsize MB Retrieve-Dauer: ${retrieve_time} s" | mail -s "Retrieve Job $archive_id beendet" maeuseba@slub-dresden.de,gerhardt@slub-dresden.de,ehrlich@slub-dresden.de
	
	
else
	echo "[FE] `date +%Y%m%d\ %T` Fehler beim untar. $RETRIEVE_DIR/$archive_id/images/scans_tif/00000001.tif nicht gefunden." >> $LOGFILE
	`rm -f $LOCKFILE 2>&1 >> $LOGFILE`
	exit 1;
fi

`rm -f $workfile`
`rm -f $tarballpath`
`rm -f $LOCKFILE 2>&1 >> $LOGFILE`
exit 0
