#!/bin/bash

######################################
#
# docs2retrieve.sh
#
#       Syntax: docs2retrieve.sh.sh <Basisordner> <Job-ID> <dsm.opt>
#
#
#
#
#
#
#
#
#
######################################

SCRIPTNAME=`basename $0`

# Pfad zu dsmc (Archiv Client)
DSMC_BINPATH="/opt/tivoli/tsm/client/ba/bin"

# Logfile
LOGFILE="/var/log/jobs/archive/$(hostname)_archive_processing_`date +%Y%m%d`.log"

# Script zur MD5 Erstellung
CREATE_MD5='perl /opt/scripts/create_md5.pl'

starttime=$[`date +%s`]

# Logfile erstellen
echo "[OK] `date +%Y%m%d\ %T` START PID: $$ $0 $*" >> $LOGFILE

# Einige checks
if [ $# -lt 3 ]; then
        echo "[FE] `date +%Y%m%d\ %T` docs2retrieve.sh ENDE Zu wenig Parameter uebergeben." >> $LOGFILE
        exit 1
fi

if [ ! -e ${DSMC_BINPATH}/dsmc ]; then
        echo "[FE] `date +%Y%m%d\ %T` docs2retrieve.sh ENDE Archiv-Client dsmc in $DSMC_BINPATH nicht gefunden." >> $LOGFILE
        exit 1
fi

# Parameter uebergeben
basefolder=$1
archive_id=$2
tsm_optfile=$3

readyfiledir="${basefolder}/docs2retrieve"

# Ausgabe Verzeichnisse
RETRIEVE_DIR="${basefolder}/retrieved"

# Herausfinden, zu welchem Dienst das Archiv gehoert (z.B. goobi, fotothek, ...)
service=${archive_id%%_*}       # pattern matching, alles vor dem ersten _ wird zurueck gegeben

if [ ! -e $tsm_optfile ]; then
        echo "[FE] `date +%Y%m%d\ %T` $tsm_optfile existiert nicht." >> $LOGFILE
        exit 1l
fi


LOCKFILE="/var/locks/"${service}"_docs2retrieve.lock"
if [ -e $LOCKFILE ]; then
        echo "[FE] `date +%Y%m%d\ %T` docs2retrieve.sh ENDE Skript laeuft scheinbar schon, lockfile '$LOCKFILE' existiert." >> $LOGFILE
        `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
        exit 1
else
        echo $$ > $LOCKFILE
fi

# Readydatei umbenennen, Workdatei erstellen
if [ -e ${readyfiledir}/~${archive_id} ]; then
        echo "[FE] `date +%Y%m%d\ %T` ENDE Work-Datei $readyfiledir/~${archive_id} existiert bereits." >> $LOGFILE
        `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
        exit 1
elif [ ! -e $readyfiledir/$archive_id ]; then
        echo "[FE] `date +%Y%m%d\ %T` ENDE Readydatei $readyfiledir/${archive_id} existiert nicht." >> $LOGFILE
        `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
        exit 1
else    
#fuer Testzwecke
        #`cp -f $readyfiledir/$archive_id $basefolder/retrieve_test/$archive_id`
        `mv $readyfiledir/$archive_id $readyfiledir/~$archive_id`
  	    workfile=$readyfiledir/~$archive_id
fi

tarballpath="/${service}/${archive_id}*.tar"


#Query
dsmc_cmd="$DSMC_BINPATH/dsmc query archive \"$tarballpath\" -optfile=$tsm_optfile"
# Abfragen des Archivs, grep nach archive_id, Sortieren nach nach der archive_id absteigend, Ausgabe letzte Zeile (hoechste archive_id, damit neuestes Paket), Filtern des Archivpfades und des MD5 Hashes
#      - Beispiel dsmc_string "/goobi/goobi_6256_data_20111011065955.tar 66cac34fa21b0184714ebe7fc6471e6f"
dsmc_string=`$dsmc_cmd|grep ${archive_id}|sort -k 5,5|tail -1|awk '{print $5" "$8}'`

echo "$dsmc_cmd|grep ${archive_id}|sort -k 5,5|tail -1|awk '{print $5" "$8}'"

# Beispiel /goobi/goobi_6256_data_20111011065955.tar
tarballpath=${dsmc_string%[ ]*}
# Beispiel 66cac34fa21b0184714ebe7fc6471e6f
archive_tarmd5sum=${dsmc_string##*[ ]}

# Beispiel goobi_6256_data_20111011065955.tar
archive_id=${tarballpath##*/}

retrieve_time=$[`date +%s`]
# Retrieve
dsmc_cmd="$DSMC_BINPATH/dsmc retrieve -replace=yes ${tarballpath} ${RETRIEVE_DIR}/ -description=\"MD5 $archive_tarmd5sum\" -optfile=$tsm_optfile" 
echo "[OK] `date +%Y%m%d\ %T` Retrieve von $tarballpath beginnt." >> $LOGFILE
`$dsmc_cmd | awk '{print "[OK] '"\`date +%Y%m%d\ %T\`"' " $0}' 2>&1 >> $LOGFILE`
if [ $? != 0 ]; then
    echo "[FE] `date +%Y%m%d\ %T` Retrieve von $tarballpath nicht erfolgreich." >> $LOGFILE
	echo "[FE] `date +%Y%m%d\ %T` Kommando: ${dsmc_cmd}" >> $LOGFILE
    `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
    exit 1
fi

retrieve_time=$[`date +%s`-$retrieve_time]
if [ -e ${RETRIEVE_DIR}/${archive_id} ]; then
	tarballpath=${RETRIEVE_DIR}/${archive_id}
	byte=`du -b $tarballpath | awk '{print $1}'`
	tarsize=$(($byte / 1024 / 1024))
	
	#tarsize=$tarsize / 1024 / 1024
else
	echo "[FE] `date +%Y%m%d\ %T` ${RETRIEVE_DIR}/${archive_id} nicht vorhanden." >> $LOGFILE
    `rm -f $LOCKFILE 2>&1 >> $LOGFILE`
    exit 1
fi

# MD5 Pruefsumme des Tarballs bilden und mit Archivdescription vergleichen
tarmd5sum=`nice -n 19 $CREATE_MD5 $tarballpath`
if [ "${tarmd5sum}" == "${archive_tarmd5sum}" ]; then
	echo "[OK] `date +%Y%m%d\ %T` Pruefsummenvergleich erfolgreich: MD5: $tarmd5sum Archiv-MD5: $archive_tarmd5sum" >> $LOGFILE
else
	echo "[FE] `date +%Y%m%d\ %T` Pruefsummenvergleich gescheitert: MD5: $tarmd5sum Archiv-MD5: $archive_tarmd5sum" >> $LOGFILE
	`rm -f $LOCKFILE 2>&1 >> $LOGFILE`
	exit 1;
fi

# untar
if [ -e $tarballpath ]; then
	untar_cmd="tar -x -p -f $tarballpath"
else
	echo "[FE] `date +%Y%m%d\ %T` Abbruch, $tarballpath existiert nicht"
fi

# .tar entfernen
archive_id=${archive_id%\.*}

cd $RETRIEVE_DIR
echo "[OK] `date +%Y%m%d\ %T` Enpacken des Tarballs." >> $LOGFILE
untar_string=`$untar_cmd | awk '{print "[OK] '"\`date +%Y%m%d\ %T\`"' " $0}' 2>&1 >> $LOGFILE`
if [[ -e $RETRIEVE_DIR/$archive_id/"images/scans_tif/00000001.tif" || -e $RETRIEVE_DIR/$archive_id/"images/scans_tif/00000001.TIF" ]]; then
	duration=$[`date +%s`-$starttime]
	duration_string="$[$duration/3600]h $[$duration %3600 /60]min $[$duration%60]s"
	echo "[OK] `date +%Y%m%d\ %T` ENDE Retrieve $0 $* Dauer: $duration s ($duration_string) Tarballgroesse: $tarsize MB Retrieve-Dauer: ${retrieve_time} s" >> $LOGFILE
	echo "[OK] `date +%Y%m%d\ %T` ENDE Retrieve $0 $* Dauer: $duration s ($duration_string) Tarballgroesse: $tarsize MB Retrieve-Dauer: ${retrieve_time} s" | mail -s "Retrieve Job $archive_id beendet" kru@slub-dresden.de,gerhardt@slub-dresden.de,steffen.warncke@slub-dresden.de	
else
	echo "[FE] `date +%Y%m%d\ %T` Fehler beim untar. $RETRIEVE_DIR/$archive_id/images/scans_tif/00000001.tif nicht gefunden." >> $LOGFILE
	`rm -f $LOCKFILE 2>&1 >> $LOGFILE`
	exit 1;
fi
`rm -f $workfile`
`rm -f $tarballpath`
`rm -f $LOCKFILE 2>&1 >> $LOGFILE`
exit 0
