#!/bin/bash

######################################
#
# search4tsmjobs.sh
#
#       Syntax: search4tsmjobs.sh <Basisordner> <dsm.opt>
#	Dieses Script ermittelt aus den Unterordnern 
#		- doc2archive, zu archivierende Pakete
#		- doc2retrieve, aus dem Archiv wiedeherzustellende Pakete
#   und gibt die entsprechenden ID an die Scripte 
#		-Archivierung -> docs2archive.sh "Parameter"
#		-Wiederherstellung -> docs2retrieve.sh "Parameter"
#
########################################

SCRIPTNAME='search4tsmjobs.sh'
HOSTNAME=$(hostname)

# Logfile
LOGFILE="/var/log/jobs/archive/$(hostname)_archive_processing_`date +%Y%m%d`.log"

ARCHIVE_SCRIPT='/opt/scripts/docs2archive.sh'
RETRIEVE_SCRIPT='/opt/scripts/docs2retrieve.sh'

ARCHIVE_JOBDIR='docs2archive'
RETRIEVE_JOBDIR='docs2retrieve'


if [ $# -lt 2 ]; then
	echo "[EE] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} ABORT: not enough arguments" >> $LOGFILE
        exit 1
fi

#Ingestverzeichnis fuer die Uebergabe von zu archivierenden Paketen
basefolder=${1}
#Optionsdatei zum Archivierungsserver
tsm_optfile=${2}

###################################################################################################################################
# Suche im untergeordneten Verzeichnis ${basefolder}/${RETRIEVE_JOBDIR} nach wiederherzustellenden Archivpaketen
# 
# Dies ist ein vordefinierter Workflow mit archivierenden Fachabteilung
#		- Anlegen einer Dateiim ${basefolder}/${RETRIEVE_JOBDIR}
#		- Datei hat folgende Syntax: "Service_IEID_YYYYMMMDDhhmmss"
#		- Prozess schaut nach gültigem Dateinamen
#		- wenn Datei vorhanden wird Prozess für Wiederherstellung gestartet
##################################################################################################################################
readyfiledir=${basefolder}/${RETRIEVE_JOBDIR}
if [ -d $readyfiledir ]; then
        retrievejob=$(ls -tr1 $readyfiledir | grep -v "~" | grep -v " "| head -n 1)
        if [ -n "$retrievejob" ]; then
# pattern matching, alles vor dem ersten _ wird zurueck gegeben
		service=${retrievejob%%_*}
		if [ ! -e "/var/locks/"$service"_"$RETRIEVE_JOBDIR".lock" ]; then
					# Aufruf Script zum wiederherstellen vorhanden Archivpaket aus Archiv
                	$RETRIEVE_SCRIPT $basefolder $retrievejob $tsm_optfile &
		fi
        fi
fi

###############################################################################################
#Suche im untergeordneten Verzeichnis ${basefolder}/${ARCHIVE_JOBDIR} zu archivierende Pakete
# Workflow mit jeweiliger Fachabteilung:
#		- Anlegen Unterverzeichnis in${basefolder}/${ARCHIVE_JOBDIR}/"service_id"
#		- Daten in Unterverzeichnis kopieren
###############################################################################################

readyfiledir=${basefolder}/${ARCHIVE_JOBDIR}
if [ -d $readyfiledir ]; then
        archivejob=$(ls -tr1 $readyfiledir | grep -v "~" | grep -v " " | head -n 1)
        if [ -n "$archivejob" ]; then
		service=${archivejob%%_*}       # pattern matching, alles vor dem ersten _ wird zurueck gegeben
		
		if [ ! -e "/var/locks/"$service"_"$ARCHIVE_JOBDIR".lock" ]; then
			echo "[OK] `date +%Y%m%d\ %T` PID: ${$} ${SCRIPTNAME} found archivejob '${archivejob}'." >> $LOGFILE
#			sh /opt/scripts/test.sh $readyfiledir $basefolder $archivejob $tsm_optfile	
			$ARCHIVE_SCRIPT $basefolder $archivejob $tsm_optfile &
            #echo "$ARCHIVE_SCRIPT: :$basefolder: :$archivejob: :$tsm_optfile:"
			exit 0
			#echo "sh $ARCHIVE_SCRIPT $basefolder $archivejob $tsm_optfile &"
		fi
	fi
fi




